@@ -280,14 +280,14 @@ bonobo_object_trace_refs (BonoboObject *object,
 		object->priv->ao->ref_count++;
 		
 		indent = g_strnfill (++ref_indent, ' ');
-		g_printerr ("%sRef %s:[%p] to %d at %s:%d\n", indent,
+		g_printerr ("%s[%d]:Ref %s:[%p] to %d at %s:%d\n", indent, getpid(),
 			    gtk_type_name (GTK_OBJECT (object)->klass->type),
 			    object, ao->ref_count, fn, line);
 
 		g_free (indent);
 	} else { /* unref */
 		indent = g_strnfill (ref_indent--, ' ');
-		g_printerr ("%sUnRef %s:[%p] from %d at %s:%d\n", indent, 
+		g_printerr ("%s[%d]:UnRef %s:[%p] from %d at %s:%d\n", indent, getpid(),
 			    gtk_type_name (GTK_OBJECT (object)->klass->type),
 			    ao, ao->ref_count, fn, line);
 		g_free (indent);
@@ -526,7 +526,7 @@ bonobo_object_query_local_interface (BonoboObject *object,
 }
 
 static CORBA_Object
-impl_Bonobo_Unknown_query_interface (PortableServer_Servant  servant,
+impl_Bonobo_Unknown_queryInterface (PortableServer_Servant  servant,
 				     const CORBA_char       *repoid,
 				     CORBA_Environment      *ev)
 {
@@ -554,9 +554,9 @@ bonobo_object_get_epv (void)
 
 	epv = g_new0 (POA_Bonobo_Unknown__epv, 1);
 
-	epv->ref             = impl_Bonobo_Unknown_ref;
-	epv->unref           = impl_Bonobo_Unknown_unref;
-	epv->query_interface = impl_Bonobo_Unknown_query_interface;
+	epv->ref            = impl_Bonobo_Unknown_ref;
+	epv->unref          = impl_Bonobo_Unknown_unref;
+	epv->queryInterface = impl_Bonobo_Unknown_queryInterface;
 
 	return epv;
 }
@@ -666,7 +666,7 @@ bonobo_object_instance_init (GtkObject    *gtk_object,
 #ifdef BONOBO_REF_HOOKS
 	{
 		char *indent = g_strnfill (++ref_indent, ' ');
-		g_printerr ("%sCreate %s:[%p] to %d\n", indent,
+		g_printerr ("%s[%d]:Create %s:[%p] to %d\n", indent, getpid(),
 			    gtk_type_name (klass->type),
 			    ao, ao->ref_count);
 		g_free (indent);
@@ -898,7 +898,7 @@ bonobo_object_query_interface (BonoboObject *object, const char *repo_id)
        CORBA_Object retval;
 
        CORBA_exception_init(&ev);
-       retval = Bonobo_Unknown_query_interface (object->corba_objref, (CORBA_char *)repo_id, &ev);
+       retval = Bonobo_Unknown_queryInterface (object->corba_objref, (CORBA_char *)repo_id, &ev);
        if (ev._major != CORBA_NO_EXCEPTION)
                retval = CORBA_OBJECT_NIL;
        CORBA_exception_free (&ev);
