@@ -1,4 +1,12 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/**
+ * bonobo-property-listener.c: Property listener implementation.
+ *
+ * Author:
+ *	Mike Kestner (mkestner@ameritech.net)
+ *
+ * Copyright 2000, Mike Kestner
+ */
 #ifndef _BONOBO_PROPERTY_LISTENER_H_
 #define _BONOBO_PROPERTY_LISTENER_H_
 
