@@ -203,6 +203,23 @@ control_create_menus (control_data_t *control_data)
 	Bonobo_UIContainer remote_uic;
 	GdkPixbuf *pixbuf;
 
+	static char ui [] = 
+		"<Root>"
+		"	<commands>"
+		"		<cmd name=\"NewGame\" _label=\"New game\" _tip=\"Start a new game\"/>"
+		"		<cmd name=\"OpenGame\" _label=\"Open game\" _tip=\"Load a saved game\"/>"
+		"	</commands>"
+		"	<menu>"
+		"		<submenu name=\"Game\" _label=\"_Game\">"
+		"			<menuitem name=\"NewGame\" verb=\"\"/>"
+		"			<menuitem name=\"OpenGame\" verb=\"\"/>"
+		"		</submenu>"
+		"	</menu>"
+		"	<dockitem name=\"Game\">"
+		"		<toolitem name=\"NewGame\" verb=\"\"/>"
+		"	</dockitem>"
+		"</Root>";
+
 	/*
 	 * Get our container's UIContainer server.
 	 */
@@ -228,9 +245,19 @@ control_create_menus (control_data_t *control_data)
 	 */
 	bonobo_object_release_unref (remote_uic, NULL);
 
-	/* Set up the UI from an XML file. */
-        bonobo_ui_util_set_ui (control_data->uic, DATADIR,
-			       "/bonobo-application-x-mines-ui.xml", "Gnomines");
+	/* Set up the UI from the XML string. */
+	{
+		BonoboUINode *node;
+
+		node = bonobo_ui_node_from_string (ui);
+		bonobo_ui_util_translate_ui (node);
+		bonobo_ui_util_fixup_help (control_data->uic, node,
+					   DATADIR, "gnomines");
+					   
+		bonobo_ui_component_set_tree (control_data->uic, "/", node, NULL);
+
+		bonobo_ui_node_free (node);
+	}
 
 	/* Start a new game: Happy face. */
 	pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **) face_smile_xpm);
