@@ -15,24 +15,17 @@
  * Component data
  */
 typedef struct {
-  BonoboEmbeddable *embeddable;
+  BonoboControl *bonobo_object;
 
   gchar *sound;
   guint sound_len;
   
   gint update_callback_id;  
-} embeddable_data_t;
 
-/*
- * View data
- */
-typedef struct {
-	embeddable_data_t *embeddable_data;
-	
-	GtkWidget        *canvas;
-	GtkWidget        *vbox;
-	GtkWidget        *hscroll;
-	GnomeCanvasItem  *canvas_item;
-} view_data_t;
+  GtkWidget *canvas;
+  GtkWidget *vbox;
+  GtkWidget *hscroll;
+  GnomeCanvasItem *canvas_item;
+} bonobo_object_data_t;
 
 #endif /* __BONOBO_AUDIO_ULAW_H__ */
