@@ -11,31 +11,28 @@
 #include <config.h>
 #include "gshell.h"
 #include "inout.h"
-#include "menu.h"
+#include "ui.h"
 #include "properties.h"
-
-#if USING_OAF
+#include "controls.h"
 #include <liboaf/liboaf.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
 
 Application app;
 
-static void            frame_close_cb        (GtkWidget *widget);
-
-void 
-help_menu_help_gnome_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_HelpGNOME_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
 	gchar *p;
+
 	p = gnome_help_file_path ("help-browser", "default-page.html");
-	if (p) gnome_help_goto (NULL, p);
+	if (p)
+		gnome_help_goto (NULL, p);
 }
 
-void 
-help_menu_about_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_HelpAbout_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
 	static GtkWidget *about;
+
 	const gchar *authors[] = {
 		"Dietmar Maurer",
 		NULL
@@ -57,41 +54,12 @@ help_menu_about_cb (BonoboUIHandler *uih, void *data, char *path)
 	gtk_widget_show (about);
 }
 
-void 
-edit_menu_preferences_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_SettingsPreferences_cb (BonoboUIComponent *component,
+			     Frame *frame, const char *cname)
 {
-	Frame *frame;
-
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) return;
-
-	show_property_dialog (BONOBO_CONTROL_FRAME (frame->active_view_frame));
-}
-
-/*
- * Use query_interface to see if `obj' has `interface'.
- */
-gboolean
-bonobo_object_has_interface (BonoboObject *obj, char *interface)
-{
-	CORBA_Environment ev;
-	CORBA_Object requested_interface;
-	gboolean retval;
-	
-	CORBA_exception_init (&ev);
-
-	requested_interface = Bonobo_Unknown_query_interface (
-		bonobo_object_corba_objref (obj), interface, &ev);
-
-	if (!CORBA_Object_is_nil(requested_interface, &ev) && 
-	    ev._major == CORBA_NO_EXCEPTION) {
-		/* Get rid of the interface we've been passed */
-		Bonobo_Unknown_unref (requested_interface, &ev);
-		CORBA_Object_release (requested_interface, &ev);
-		retval = TRUE;
-	} else retval = FALSE;
-
-	CORBA_exception_free (&ev);
-	return retval;
+	show_property_dialog (
+		BONOBO_CONTROL_FRAME (frame->active_view_frame));
 }
 
 Frame *
@@ -102,12 +70,13 @@ get_active_frame (GtkWidget *widget)
 	Frame *frame;
 
 	g_return_val_if_fail (widget != NULL, NULL);
-	g_return_val_if_fail (GTK_IS_WIDGET(widget), NULL);
+	g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
 	top = gtk_widget_get_toplevel(widget);
 	for (l = app.frame_list;l;l = l->next) {
 		frame = (Frame *)l->data;
-		if (frame->app == top) return frame;
+		if (GTK_WIDGET (frame->win) == top)
+			return frame;
 	}
 	return NULL;
 }
@@ -145,7 +114,8 @@ static void
 user_activate_request_cb (BonoboViewFrame *view_frame, Frame *frame)
 {
 
-	if (frame->active_view_frame == view_frame) return;
+	if (frame->active_view_frame == view_frame)
+		return;
 
         if (frame->active_view_frame != NULL) {
                 bonobo_view_frame_view_deactivate (frame->active_view_frame);
@@ -176,8 +146,7 @@ view_activated_cb (BonoboViewFrame *view_frame, gboolean activated,
 		w = bonobo_view_frame_get_wrapper (view_frame);
 		//gtk_container_focus (GTK_CONTAINER(w), GTK_DIR_UP);
 		gtk_widget_grab_focus(w);
-		set_file_menu_state (frame, TRUE);
-		set_edit_menu_state (frame, TRUE);
+		frame_set_sensitive (frame, TRUE);
         } else {
 		bonobo_view_frame_set_covered (view_frame, TRUE);
 		if (view_frame == frame->active_view_frame)
@@ -185,6 +154,37 @@ view_activated_cb (BonoboViewFrame *view_frame, gboolean activated,
         }                                                   
 }
 
+static void
+zoom_level_changed_cb (GtkWidget *widget, float zoom_level, Frame *frame)
+{
+	gchar *message;
+
+	message = g_strdup_printf (_("New zoom level is %.3g."), zoom_level);
+	bonobo_ui_component_set_status (frame->component, message, NULL);
+	g_free (message);
+}
+
+static void
+buffer_create_zoomable_frame (Buffer *buffer, Frame *frame, BonoboViewFrame *view_frame)
+{
+	Bonobo_Control control;
+	Bonobo_Zoomable zoomable;
+
+	control = bonobo_control_frame_get_control (BONOBO_CONTROL_FRAME (view_frame));
+	zoomable = Bonobo_Unknown_queryInterface (control, "IDL:Bonobo/Zoomable:1.0", NULL);
+	if (zoomable != CORBA_OBJECT_NIL) {
+		g_message ("Zooming interface found");
+		buffer->zoomable_frame = bonobo_zoomable_frame_new ();
+		bonobo_zoomable_frame_bind_to_zoomable (buffer->zoomable_frame, zoomable);
+
+		gtk_signal_connect (GTK_OBJECT (buffer->zoomable_frame), "zoom_level_changed",
+				    GTK_SIGNAL_FUNC (zoom_level_changed_cb), frame);
+
+		frame_set_zoomable (frame, TRUE);
+	} else
+		frame_set_zoomable (frame, FALSE);
+}
+
 void
 buffer_add_view (Buffer *buffer, Frame *frame, gint pos)
 {
@@ -194,11 +194,11 @@ buffer_add_view (Buffer *buffer, Frame *frame, gint pos)
 
 	view_frame = bonobo_client_site_new_view_full (
 		buffer->client_site,
-		bonobo_object_corba_objref (BONOBO_OBJECT (frame->uih)),
+		bonobo_object_corba_objref (BONOBO_OBJECT (frame->container)),
 		FALSE, TRUE);
 
 	if (!view_frame) {
-		g_warning("create view failed");
+		g_warning ("create view failed");
 		return;
 	}
 
@@ -228,21 +228,15 @@ buffer_add_view (Buffer *buffer, Frame *frame, gint pos)
 	gtk_widget_show_all (box);
 
 	user_activate_request_cb (view_frame, frame);
+
+	buffer_create_zoomable_frame (buffer, frame, view_frame);
 }
 
-Buffer *
-buffer_create (const char *component_goad_id)
+static Buffer *
+real_buffer_create (BonoboObjectClient *server)
 {
 	Buffer *buffer;
 	BonoboClientSite *client_site;
-	BonoboObjectClient *server;
-
-	server = bonobo_object_activate (component_goad_id, 0);
-
-	if (!server) {
-		g_warning("Launching component failed");
-		return NULL;
-	}
 
 	client_site = bonobo_client_site_new (app.container);
 
@@ -252,6 +246,8 @@ buffer_create (const char *component_goad_id)
 		g_warning("Bind component failed");
 		return NULL;
 	}
+
+	bonobo_object_client_unref (server, NULL);
 	
 	buffer = g_new0 (Buffer, 1);
 	buffer->client_site = client_site;
@@ -264,6 +260,66 @@ buffer_create (const char *component_goad_id)
 	return buffer;
 }
 
+static Buffer *
+real_buffer_create_embeddable (const char *component_goad_id)
+{
+	BonoboObjectClient *server;
+
+	server = bonobo_object_activate (component_goad_id, 0);
+
+	if (!server) {
+		g_warning ("Launching component failed");
+		return NULL;
+	}
+
+	return real_buffer_create (server);
+}
+
+static Buffer *
+real_buffer_create_control (const char *component_goad_id)
+{
+	BonoboObjectClient *server;
+
+	server = gshell_control_wrapper (component_goad_id);
+	if (!server) {
+		g_warning("Launching component failed");
+		return NULL;
+	}
+
+	return real_buffer_create (server);
+}
+
+Buffer *
+buffer_create (const char *component_goad_id)
+{
+	Buffer *retval;
+        OAF_ServerInfoList *servers;
+	CORBA_Environment ev;
+	gchar *query;
+
+        CORBA_exception_init (&ev);
+	query = g_strdup_printf ("(iid == '%s') AND repo_ids.has('IDL:Bonobo/Embeddable:1.0')",
+				 component_goad_id);
+        servers = oaf_query (query, NULL, &ev);
+        g_free (query);
+        CORBA_exception_free (&ev);
+
+	if ((servers != NULL) && (servers->_length > 0))
+		retval = real_buffer_create_embeddable (component_goad_id);
+	else
+		retval = real_buffer_create_control (component_goad_id);
+
+	CORBA_free (servers);
+
+	return retval;
+}
+
+Buffer *
+buffer_create_for_control (const char *component_goad_id)
+{
+	return real_buffer_create_control (component_goad_id);
+}
+
 static GtkWidget *
 find_view_frame_pos (Frame *frame, BonoboViewFrame *view_frame, gint *pos)
 {
@@ -280,7 +336,9 @@ find_view_frame_pos (Frame *frame, BonoboViewFrame *view_frame, gint *pos)
 
 	if (pos) *pos = i;
 
-	if (o) return GTK_WIDGET (o);
+	if (o)
+		return GTK_WIDGET (o);
+
 	return NULL;
 }
 
@@ -297,67 +355,43 @@ view_remove (Frame *frame, BonoboViewFrame *view_frame)
 
 	b = find_view_frame_pos (frame, view_frame, &pos);
 	
+	gtk_widget_destroy (w);
 	bonobo_object_unref (BONOBO_OBJECT (view_frame));
-	if (b) gtk_widget_destroy (b);
+
+	if (b)
+		gtk_widget_destroy (b);
+
 	return pos;
 }
 
 static void
-frame_close_cb (GtkWidget *widget)
+frame_close_cb (GtkWidget *widget, Frame *frame)
 {
-	Frame *frame;
 	BonoboViewFrame *view_frame;
 	GList *v;
 
-	frame = get_active_frame (widget);
-
 	while ((v = frame->view_list)) {
 		view_frame = (BonoboViewFrame *)v->data;
 		view_remove (frame, view_frame);
 	}
 
 	app.frame_list = g_list_remove (app.frame_list, frame);
-	gtk_widget_destroy (widget);
-	if (!g_list_length(app.frame_list)) gtk_main_quit ();
+	gtk_widget_destroy (GTK_WIDGET (frame->win));
+	if (!g_list_length(app.frame_list))
+		gtk_main_quit ();
 }
 
-void 
-file_menu_exit_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_FileExit_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
 	bonobo_object_unref (BONOBO_OBJECT (app.container));
 	gtk_main_quit ();
 }
 
-void
-set_buffer_cb (BonoboUIHandler *uih, void *buffer,
-	       const char *path)
+static void
+verb_WindowClose_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Buffer *tmp;
-	Frame *frame;
-	BonoboViewFrame *view_frame;
-	gint pos = -1;
-
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
-
-	if ((view_frame = get_active_view_frame (frame))) {
-		tmp = gtk_object_get_data(GTK_OBJECT(view_frame), 
-					  "gshell:buffer");
-		if (tmp == buffer) return;
-		pos = view_remove (frame, view_frame);
-	}
-	buffer_add_view (buffer, frame, pos);
-}
-
-void 
-view_menu_delete_window_cb (BonoboUIHandler *uih, void *data, char *path)
-{
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-	
-	frame_close_cb (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
+	frame_close_cb (NULL, frame);
 }
 
 static Frame *
@@ -367,28 +401,27 @@ frame_create ()
 	GtkWidget *statusbar;
 
 	frame = g_new0 (Frame, 1);
-	frame->app = gnome_app_new ("gshell", "Gnome Shell");
+	frame->win = BONOBO_WINDOW (bonobo_window_new ("gshell", "Gnome Shell"));
 
-	gtk_window_set_default_size (GTK_WINDOW (frame->app), 640, 400);
-	gtk_window_set_policy (GTK_WINDOW (frame->app), TRUE, TRUE, FALSE);
+	gtk_window_set_default_size (GTK_WINDOW (frame->win), 640, 400);
+	gtk_window_set_policy (GTK_WINDOW (frame->win), TRUE, TRUE, FALSE);
 
-	gtk_signal_connect(GTK_OBJECT(frame->app), "delete_event",
-			   GTK_SIGNAL_FUNC(frame_close_cb), NULL);
+	gtk_signal_connect (GTK_OBJECT (frame->win), "delete_event",
+			    GTK_SIGNAL_FUNC (frame_close_cb), frame);
 
 	statusbar = gtk_statusbar_new ();
 
 	frame->vbox = gtk_vbox_new (FALSE, 0);
-	gnome_app_set_contents (GNOME_APP (frame->app), frame->vbox);
-	gnome_app_set_statusbar (GNOME_APP (frame->app), statusbar);
+	bonobo_window_set_contents (frame->win, frame->vbox);
 
-	frame->uih = bonobo_ui_handler_new ();
-	bonobo_ui_handler_set_app (frame->uih, GNOME_APP (frame->app));
-	bonobo_ui_handler_set_statusbar (frame->uih, statusbar);
+	frame->container = bonobo_ui_container_new ();
+	bonobo_ui_container_set_win (frame->container, frame->win);
 
-	frame_create_menus (frame);
-	frame_create_toolbar (frame);
+	frame_create_ui (frame);
+	frame_set_sensitive (frame, FALSE);
+	frame_set_zoomable (frame, FALSE);
 
-	gtk_widget_show_all (frame->app);
+	gtk_widget_show_all (GTK_WIDGET (frame->win));
 
 	app.frame_list = g_list_append (app.frame_list, frame);
 
@@ -409,127 +442,116 @@ get_active_view_frame (Frame *frame)
 
 	}
 
-       	if (w) return gtk_object_get_data (GTK_OBJECT (w), 
-					   "gshell:view_frame");
+       	if (w)
+		return gtk_object_get_data (GTK_OBJECT (w), 
+					    "gshell:view_frame");
 
 	return NULL;
 }
 
-void 
-view_menu_new_window_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_WindowCreateNew_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Frame *frame;
 	BonoboViewFrame *view_frame;
 	Buffer *buffer = NULL;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
-
 	if ((view_frame = get_active_view_frame (frame))) {
 		buffer = gtk_object_get_data(GTK_OBJECT(view_frame), 
 					     "gshell:buffer");
 	}
 
 	frame = frame_create ();
-	if (buffer) buffer_add_view (buffer, frame, -1);
+	if (buffer)
+		buffer_add_view (buffer, frame, -1);
 	update_buffer_menu ();
 }
 
-void 
-view_menu_split_window_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_WindowSplit_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Frame *frame;
 	BonoboViewFrame *view_frame;
 	Buffer *buffer = NULL;
 	gint pos;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
-
 	if ((view_frame = get_active_view_frame (frame))) {
 		find_view_frame_pos (frame, view_frame, &pos);
 		buffer = gtk_object_get_data(GTK_OBJECT(view_frame), 
 					     "gshell:buffer");
-		if (buffer) buffer_add_view (buffer, frame, pos);
+		if (buffer)
+			buffer_add_view (buffer, frame, pos);
 	}
 }
 
-void 
-view_menu_one_window_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_WindowOne_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Frame *frame;
 	BonoboViewFrame *view_frame, *vf;
 	GList *v;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 	if ((view_frame = get_active_view_frame (frame))) {
 		for (v = frame->view_list; v;) {
-			vf = (BonoboViewFrame *)v->data;
+			vf = (BonoboViewFrame *) v->data;
 			v = v->next;
-			if (view_frame != vf) view_remove (frame, vf);
+			if (view_frame != vf)
+				view_remove (frame, vf);
 		}
 	}
 }
 
-void 
-file_menu_kill_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_FileKill_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Frame *frame;
 	Buffer *buffer=NULL;
 	BonoboViewFrame *view_frame;
 	GList *f,*v,*b;
-	gchar buf[100];
-
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) return;
+	gchar *path;
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		buffer = gtk_object_get_data(GTK_OBJECT(view_frame), 
 					     "gshell:buffer");
-	} else return;	  
+	} else
+		return;	  
 	
-	if (!buffer) return;	  
+	if (!buffer)
+		return;	  
 
 	app.buffer_list = g_list_remove (app.buffer_list, buffer);
 
 	for (f = app.frame_list; f; f = f->next) {
-		frame = (Frame *)f->data;
+		frame = (Frame *) f->data;
+
 		for (v = frame->view_list; v;) {
-			view_frame = (BonoboViewFrame *)v->data;
+
+			view_frame = (BonoboViewFrame *) v->data;
 			v = v->next;
-			if (buffer == gtk_object_get_data
-			    (GTK_OBJECT(view_frame), "gshell:buffer")) {
+			if (buffer == gtk_object_get_data (
+				GTK_OBJECT(view_frame), "gshell:buffer")) {
 				view_remove (frame, view_frame);
-				if (!g_list_length (GTK_BOX(frame->vbox)->children)) {
-					if ((b = g_list_last (app.buffer_list))) {
-						buffer_add_view ((Buffer *)b->data, frame, -1);
-					} else {
-						set_file_menu_state (frame, FALSE);
-						set_edit_menu_state (frame, FALSE);
-					}
+
+				if (!g_list_length (GTK_BOX (frame->vbox)->children)) {
+
+					if ((b = g_list_last (app.buffer_list)))
+						buffer_add_view ((Buffer *) b->data,
+								 frame, -1);
+					else
+						frame_set_sensitive (frame, FALSE);
 				}
 			}
 		}
 	}
 
-	bonobo_object_unref (BONOBO_OBJECT(buffer->client_site));
+	bonobo_object_unref (BONOBO_OBJECT (buffer->client_site));
 
-	for (f = app.frame_list; f; f = f->next) {
-		uih = ((Frame *)f->data)->uih;
-		sprintf (buf, "/Buffers/(%d)",buffer->menu_id);
-		bonobo_ui_handler_menu_remove (uih, buf);		
+	path = g_strdup_printf ("/commands/%s", buffer->verb);
+	bonobo_ui_component_rm (frame->component, path, NULL);
+	g_free (path);
+
+	update_buffer_menu ();
+
+	if (buffer->name) {
+		g_free (buffer->name);
+		buffer->name = NULL;
 	}
-
-	if (buffer->name) g_free (buffer->name);
 	g_free (buffer);
 }
 
@@ -542,6 +564,70 @@ open_files (Frame *frame, int argc, char **argv)
 		file_open (frame, argv [i]);
 }
 
+static void
+zoom_custom_cb (gchar *string, gpointer user_data)
+{
+	BonoboViewFrame *view_frame;
+	Frame *frame = user_data;
+	gchar *end = NULL;
+	double zoom_level;
+
+	if (string == NULL)
+		return;
+
+	zoom_level = g_strtod (string, &end);
+	if (end && *end != '\x00') {
+		g_warning ("Invalid zoom level `%s'", string);
+		return;
+	}
+
+	view_frame = get_active_view_frame (frame);
+	if (!view_frame)
+		return;
+
+	bonobo_view_frame_set_zoom_factor (view_frame, zoom_level);
+}
+
+static void
+zoom_custom (Frame *frame)
+{
+	GtkWidget *dialog;
+
+	dialog = gnome_request_dialog (FALSE, _("Set zoom level:"), NULL, 10,
+				       zoom_custom_cb, frame, GTK_WINDOW (frame->win));
+
+	gnome_dialog_run (GNOME_DIALOG (dialog));
+}
+
+static void
+verb_Zoom_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
+{
+	BonoboViewFrame *view_frame;
+	Buffer *buffer = NULL;
+
+	view_frame = get_active_view_frame (frame);
+	if (!view_frame)
+		return;
+
+	buffer = gtk_object_get_data (GTK_OBJECT (view_frame), "gshell:buffer");
+	if (!buffer)
+		return;
+
+	if (!buffer->zoomable_frame)
+		return;
+
+	if (!strcmp (cname, "ZoomIn"))
+		bonobo_zoomable_frame_zoom_in (buffer->zoomable_frame);
+	else if (!strcmp (cname, "ZoomOut"))
+		bonobo_zoomable_frame_zoom_out (buffer->zoomable_frame);
+	else if (!strcmp (cname, "ZoomToFit"))
+		bonobo_zoomable_frame_zoom_to_fit (buffer->zoomable_frame);
+	else if (!strcmp (cname, "ZoomToDefault"))
+		bonobo_zoomable_frame_zoom_to_default (buffer->zoomable_frame);
+	else
+		zoom_custom (frame);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -554,26 +640,18 @@ main (int argc, char **argv)
 
 	CORBA_exception_init (&ev);
 
-#if USING_OAF
 	gnome_init_with_popt_table ("gshell", "1.0",
 				    argc, argv,
 				    oaf_popt_options, 0, NULL);
-#else
-	gnome_CORBA_init ("gshell", "1.0", &argc, argv, 0, &ev);
-#endif
 
 	CORBA_exception_free (&ev);
 
-#if USING_OAF
 	orb = oaf_init (argc, argv);
-#else
-	orb = gnome_CORBA_ORB ();
-#endif
 
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
 		g_error (_("Could not initialize Bonobo!"));
 
-	app.container = bonobo_container_new ();
+	app.container = bonobo_item_container_new ();
 	gtk_signal_connect (GTK_OBJECT (app.container), "system_exception",
 			    container_system_exception_cb, NULL);
 
@@ -587,3 +665,22 @@ main (int argc, char **argv)
 
 	return 0;
 }
+
+BonoboUIVerb gshell_verbs[] = {
+	BONOBO_UI_UNSAFE_VERB ("FileKill", verb_FileKill_cb),
+	BONOBO_UI_UNSAFE_VERB ("FileExit", verb_FileExit_cb),
+	BONOBO_UI_UNSAFE_VERB ("SettingsPreferences", verb_SettingsPreferences_cb),
+	BONOBO_UI_UNSAFE_VERB ("WindowCreateNew", verb_WindowCreateNew_cb),
+	BONOBO_UI_UNSAFE_VERB ("WindowClose", verb_WindowClose_cb),
+	BONOBO_UI_UNSAFE_VERB ("WindowSplit", verb_WindowSplit_cb),
+	BONOBO_UI_UNSAFE_VERB ("WindowOne", verb_WindowOne_cb),
+	BONOBO_UI_UNSAFE_VERB ("ZoomIn", verb_Zoom_cb),
+	BONOBO_UI_UNSAFE_VERB ("ZoomOut", verb_Zoom_cb),
+	BONOBO_UI_UNSAFE_VERB ("ZoomToFit", verb_Zoom_cb),
+	BONOBO_UI_UNSAFE_VERB ("ZoomToDefault", verb_Zoom_cb),
+	BONOBO_UI_UNSAFE_VERB ("WindowZoom", verb_Zoom_cb),
+	BONOBO_UI_UNSAFE_VERB ("HelpGNOME", verb_HelpGNOME_cb),
+	BONOBO_UI_UNSAFE_VERB ("HelpAbout", verb_HelpAbout_cb),
+	BONOBO_UI_VERB_END
+};
+
