@@ -10,8 +10,11 @@
  */
 
 #include <config.h>
+#include <fcntl.h>
 #include "inout.h"
-#include "menu.h"
+#include "ui.h"
+
+static gint last_verb_id = 0;
 
 static void
 buffer_save_pf (Buffer *buffer, gchar *filename)
@@ -24,7 +27,7 @@ buffer_save_pf (Buffer *buffer, gchar *filename)
 	
 	CORBA_exception_init (&ev);
 
-	persist = Bonobo_Unknown_query_interface (
+	persist = Bonobo_Unknown_queryInterface (
 	        bonobo_object_corba_objref (BONOBO_OBJECT (buffer->server)),
 		"IDL:Bonobo/PersistFile:1.0",
 		&ev);
@@ -38,7 +41,7 @@ buffer_save_pf (Buffer *buffer, gchar *filename)
 	/* fixme: only save when dirty - this is currently not 
 	   supported by most components */
 	/*
-	if (!Bonobo_PersistFile_is_dirty (persist, &ev)) {
+	if (!Bonobo_PersistFile_isDirty (persist, &ev)) {
 	        g_warning ("No changes need to be saved");
 		Bonobo_Unknown_unref (persist, &ev);
 		CORBA_exception_free (&ev);
@@ -71,7 +74,7 @@ buffer_load_pf (Buffer *buffer, gchar *filename)
 	
 	CORBA_exception_init (&ev);
 
-	persist = Bonobo_Unknown_query_interface (
+	persist = Bonobo_Unknown_queryInterface (
 	        bonobo_object_corba_objref (BONOBO_OBJECT (buffer->server)),
 		"IDL:Bonobo/PersistFile:1.0",
 		&ev);
@@ -106,7 +109,8 @@ buffer_save_ps (Buffer *buffer, gchar *filename)
 	g_return_if_fail (buffer != NULL);
 	g_return_if_fail (filename != NULL);
 	
-	if (!(stream = bonobo_stream_fs_open (filename, Bonobo_Storage_WRITE))) {
+	if (!(stream = bonobo_stream_open (
+		"fs", filename, Bonobo_Storage_WRITE, O_WRONLY))) {
 		char *error_msg;
 		error_msg = g_strdup_printf (_("Could not save file %s"), 
 					     filename);
@@ -117,7 +121,7 @@ buffer_save_ps (Buffer *buffer, gchar *filename)
 
 	CORBA_exception_init (&ev);
 
-	persist = Bonobo_Unknown_query_interface (
+	persist = Bonobo_Unknown_queryInterface (
 	        bonobo_object_corba_objref (BONOBO_OBJECT (buffer->server)),
 		"IDL:Bonobo/PersistStream:1.0",
 		&ev);
@@ -131,7 +135,7 @@ buffer_save_ps (Buffer *buffer, gchar *filename)
 	/* fixme: only save when dirty - this is currently not 
 	   supported by most components */
 	/*
-	if (!Bonobo_PersistStream_is_dirty (persist, &ev)) {
+	if (!Bonobo_PersistStream_isDirty (persist, &ev)) {
 		g_warning ("No changes need to be saved");
 		Bonobo_Unknown_unref (persist, &ev);
 		CORBA_exception_free (&ev);
@@ -166,7 +170,8 @@ buffer_load_ps (Buffer *buffer, gchar *filename)
 	g_return_if_fail (buffer != NULL);
 	g_return_if_fail (filename != NULL);
 	
-	if (!(stream = bonobo_stream_fs_open (filename, Bonobo_Storage_READ))) {
+	if (!(stream = bonobo_stream_open (
+		"fs", filename, Bonobo_Storage_READ, O_RDONLY))) {
 		char *error_msg;
 		error_msg = g_strdup_printf (_("Could not open file %s"), 
 					     filename);
@@ -177,7 +182,7 @@ buffer_load_ps (Buffer *buffer, gchar *filename)
 
 	CORBA_exception_init (&ev);
 
-	persist = Bonobo_Unknown_query_interface (
+	persist = Bonobo_Unknown_queryInterface (
 	        bonobo_object_corba_objref (BONOBO_OBJECT (buffer->server)),
 		"IDL:Bonobo/PersistStream:1.0",
 		&ev);
@@ -206,42 +211,34 @@ buffer_load_ps (Buffer *buffer, gchar *filename)
 }
 
 static void
-file_save_as_cb (GtkWidget *widget, BonoboUIHandler *uih)
+file_save_as_cb (GtkWidget *widget, Frame *frame)
 {
 	Buffer *buffer;
-	Frame *frame;
 	BonoboViewFrame *view_frame;
 	gchar *name;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
 	name = strdup(gtk_file_selection_get_filename(app.fs));
 	gtk_widget_destroy (GTK_WIDGET(app.fs));
 
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) {
-		g_warning ("unable to get active frame");
-		g_free (name);
-		return;
-	}
-
 	if (!(view_frame = get_active_view_frame (frame))) {
 		g_warning ("unable to get active view frame");
 		g_free (name);
 		return;
 	}
 
-	if (!(buffer = gtk_object_get_data(GTK_OBJECT(view_frame),"buffer"))) {
+	if (!(buffer = gtk_object_get_data(GTK_OBJECT(view_frame),"gshell:buffer"))) {
 		g_warning ("unable to get active buffer");
 		g_free (name);
 		return;
 	}
 
-	if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-				       "IDL:Bonobo/PersistFile:1.0")) {
+	if (bonobo_object_client_has_interface(buffer->server,
+					       "IDL:Bonobo/PersistFile:1.0",
+					       NULL)) {
 		buffer_save_pf (buffer, name);
-	} else if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-					      "IDL:Bonobo/PersistStream:1.0")) {
+	} else if (bonobo_object_client_has_interface(buffer->server,
+						      "IDL:Bonobo/PersistStream:1.0",
+						      NULL)) {
 		buffer_save_ps (buffer, name);
 	} else {
 		g_warning ("no storage interface found");
@@ -250,13 +247,37 @@ file_save_as_cb (GtkWidget *widget, BonoboUIHandler *uih)
 	g_free (name);
 }
 
+typedef struct
+{
+	Frame *frame;
+	Buffer *buffer;
+} BufferSelect_CbData;
+
+static void
+verb_BufferSelect_cb (BonoboUIComponent *component, BufferSelect_CbData *cb_data, const char *cname)
+{
+	Buffer *tmp;
+	BonoboViewFrame *view_frame;
+	gint pos = -1;
+
+	g_message ("set_buffer: `%s'", cname);
+
+	if ((view_frame = get_active_view_frame (cb_data->frame))) {
+		tmp = gtk_object_get_data(GTK_OBJECT(view_frame), 
+					  "gshell:buffer");
+		if (tmp == cb_data->buffer) return;
+		pos = view_remove (cb_data->frame, view_frame);
+	}
+	buffer_add_view (cb_data->buffer, cb_data->frame, pos);
+}
+
 void
 file_open (Frame *frame, gchar *name)
 {
 	const gchar *mime, *bid;
-	static gint menu_id = 0;
 	Buffer *buffer;
 	BonoboViewFrame *view_frame;
+	BufferSelect_CbData *cb_data;
 	gint pos = -1;
 
 	if (!g_file_test(name, G_FILE_TEST_ISFILE)) return;
@@ -285,18 +306,29 @@ file_open (Frame *frame, gchar *name)
 		return;
 	}
 	
-	buffer->name = name;
-	buffer->menu_id = menu_id++;
+	buffer->name = g_strdup (name);
+	buffer->verb_id = ++last_verb_id;
+	buffer->verb = g_strdup_printf ("SelectBuffer%d", buffer->verb_id);
+
+	cb_data = g_new0 (BufferSelect_CbData, 1);
+	cb_data->frame = frame;
+	cb_data->buffer = buffer;
+
+	bonobo_ui_component_add_verb_full (frame->component, buffer->verb,
+					   (BonoboUIVerbFn) verb_BufferSelect_cb,
+					   cb_data, (GDestroyNotify) g_free);
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		pos = view_remove (frame, view_frame);
 	}
 
-	if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-					"IDL:Bonobo/PersistFile:1.0")) {
+	if (bonobo_object_client_has_interface(buffer->server,
+					       "IDL:Bonobo/PersistFile:1.0",
+					       NULL)) {
 		buffer_load_pf (buffer, name);
-	} else if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-					       "IDL:Bonobo/PersistStream:1.0")) {
+	} else if (bonobo_object_client_has_interface(buffer->server,
+						      "IDL:Bonobo/PersistStream:1.0",
+						      NULL)) {
 		buffer_load_ps (buffer, name);
 	} else {
 		g_warning ("no storage interface found");
@@ -307,32 +339,24 @@ file_open (Frame *frame, gchar *name)
 }
 
 static void
-file_open_cb (GtkWidget *widget, BonoboUIHandler *uih)
+file_open_cb (GtkWidget *widget, Frame *frame)
 {
 	gchar *name;
-	Frame *frame;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) {
-		g_warning ("unable to get active frame");
-		return;
-	}
-	
 	name = strdup(gtk_file_selection_get_filename(app.fs));
 	gtk_widget_destroy (GTK_WIDGET(app.fs));
 	app.fs = NULL;
 	if (!name) return;
 
 	file_open(frame, name);
+	g_free(name);
 }
 
-void  
-file_menu_open_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_FileOpen_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
+	g_return_if_fail(component != NULL);
+	g_return_if_fail(BONOBO_IS_UI_COMPONENT(component));
 	
 	app.fs=GTK_FILE_SELECTION(gtk_file_selection_new(_("Open")));
 	gtk_file_selection_hide_fileop_buttons(app.fs);
@@ -343,58 +367,237 @@ file_menu_open_cb (BonoboUIHandler *uih, void *data, char *path)
 	gtk_signal_connect(GTK_OBJECT(app.fs->ok_button), 
 			   "clicked",
 			   (GtkSignalFunc)file_open_cb,
-			   (gpointer)uih);
+			   (gpointer) frame);
 
 	gtk_widget_show(GTK_WIDGET(app.fs));
 	gtk_window_set_modal (GTK_WINDOW(app.fs), TRUE);
 }
 
-void 
-file_menu_save_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_LaunchControl_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Buffer *buffer;
-	Frame *frame;
+	const gchar *interfaces[] = { "IDL:Bonobo/Control:1.0", NULL };
 	BonoboViewFrame *view_frame;
+	BufferSelect_CbData *cb_data;
+	GtkWidget *selector;
+	Buffer *buffer;
+	gchar *goad_id, *name;
+	gint pos = -1, n;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
+	g_return_if_fail(component != NULL);
+	g_return_if_fail(BONOBO_IS_UI_COMPONENT(component));
 
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) {
-		g_warning ("unable to get active frame");
+	selector = bonobo_selector_new (_("Launch component"), interfaces);
+	n = gnome_dialog_run (GNOME_DIALOG (selector));
+
+	if (n == -1)
+		return;
+
+	if (n != 0) {
+	    gtk_widget_destroy (selector);
+	    return;
+	}
+
+	goad_id = bonobo_selector_get_selected_id (BONOBO_SELECTOR (selector));
+	name = bonobo_selector_get_selected_name (BONOBO_SELECTOR (selector));
+
+	gtk_widget_destroy (selector);
+
+	if (!(buffer = buffer_create_for_control (goad_id))) {
+		g_warning ("unable to create the bonobo component");
 		return;
 	}
+	
+	buffer->name = g_strdup (name);
+	buffer->verb_id = ++last_verb_id;
+	buffer->verb = g_strdup_printf ("SelectBuffer%d", buffer->verb_id);
+
+	cb_data = g_new0 (BufferSelect_CbData, 1);
+	cb_data->frame = frame;
+	cb_data->buffer = buffer;
+
+	g_free (goad_id);
+	g_free (name);
+
+	bonobo_ui_component_add_verb_full (frame->component, buffer->verb,
+					   (BonoboUIVerbFn) verb_BufferSelect_cb,
+					   cb_data, (GDestroyNotify) g_free);
+
+	if ((view_frame = get_active_view_frame (frame))) {
+		pos = view_remove (frame, view_frame);
+	}
+
+	buffer_add_view (buffer, frame, pos);
+	update_buffer_menu ();
+}
+
+static void
+verb_LaunchEmbeddable_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
+{
+	const gchar *interfaces[] = { "IDL:Bonobo/Embeddable:1.0", NULL };
+	BonoboViewFrame *view_frame;
+	BufferSelect_CbData *cb_data;
+	GtkWidget *selector;
+	Buffer *buffer;
+	gchar *goad_id, *name;
+	gint pos = -1, n;
+
+	g_return_if_fail(component != NULL);
+	g_return_if_fail(BONOBO_IS_UI_COMPONENT(component));
+
+	selector = bonobo_selector_new (_("Launch component"), interfaces);
+	n = gnome_dialog_run (GNOME_DIALOG (selector));
+
+	if (n == -1)
+		return;
+
+	if (n != 0) {
+	    gtk_widget_destroy (selector);
+	    return;
+	}
+
+	goad_id = bonobo_selector_get_selected_id (BONOBO_SELECTOR (selector));
+	name = bonobo_selector_get_selected_name (BONOBO_SELECTOR (selector));
+
+	gtk_widget_destroy (selector);
+
+	if (!(buffer = buffer_create (goad_id))) {
+		g_warning ("unable to create the bonobo component");
+		return;
+	}
+	
+	buffer->name = g_strdup (name);
+	buffer->verb_id = ++last_verb_id;
+	buffer->verb = g_strdup_printf ("SelectBuffer%d", buffer->verb_id);
+
+	cb_data = g_new0 (BufferSelect_CbData, 1);
+	cb_data->frame = frame;
+	cb_data->buffer = buffer;
+
+	g_free (goad_id);
+	g_free (name);
+
+	bonobo_ui_component_add_verb_full (frame->component, buffer->verb,
+					   (BonoboUIVerbFn) verb_BufferSelect_cb,
+					   cb_data, (GDestroyNotify) g_free);
+
+	if ((view_frame = get_active_view_frame (frame))) {
+		pos = view_remove (frame, view_frame);
+	}
+
+	buffer_add_view (buffer, frame, pos);
+	update_buffer_menu ();
+}
+
+static void
+file_load (Frame *frame, gchar *name)
+{
+	BonoboViewFrame *view_frame;
+	Buffer *buffer;
+	gint pos = -1;
+
+	if (!g_file_test(name, G_FILE_TEST_ISFILE)) return;
+	
+	if (!(view_frame = get_active_view_frame (frame))) {
+		g_warning ("unable to get active view frame");
+		return;
+	}
+
+	if (!(buffer = gtk_object_get_data(GTK_OBJECT(view_frame),"gshell:buffer"))) {
+		g_warning ("unable to get active buffer");
+		return;
+	}
+
+	if (bonobo_object_client_has_interface(buffer->server,
+					       "IDL:Bonobo/PersistFile:1.0",
+					       NULL)) {
+		buffer_load_pf (buffer, name);
+	} else if (bonobo_object_client_has_interface(buffer->server,
+						      "IDL:Bonobo/PersistStream:1.0",
+						      NULL)) {
+		buffer_load_ps (buffer, name);
+	} else {
+		g_warning ("no storage interface found");
+	}
+
+	pos = view_remove (frame, view_frame);
+
+	g_free (buffer->name);
+	buffer->name = g_strdup (name);
+
+	buffer_add_view (buffer, frame, pos);
+	update_buffer_menu ();
+}
+
+static void
+file_load_cb (GtkWidget *widget, Frame *frame)
+{
+	gchar *name;
+
+	name = strdup(gtk_file_selection_get_filename(app.fs));
+	gtk_widget_destroy (GTK_WIDGET(app.fs));
+	app.fs = NULL;
+	if (!name) return;
+
+	file_load(frame, name);
+	g_free(name);
+}
+
+static void
+verb_FileLoad_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
+{
+	g_return_if_fail(component != NULL);
+	g_return_if_fail(BONOBO_IS_UI_COMPONENT(component));
+	
+	app.fs=GTK_FILE_SELECTION(gtk_file_selection_new(_("Load")));
+	gtk_file_selection_hide_fileop_buttons(app.fs);
+	gtk_signal_connect_object(GTK_OBJECT (app.fs->cancel_button), 
+				  "clicked",
+				  (GtkSignalFunc) gtk_widget_destroy,
+				  (gpointer)app.fs);
+	gtk_signal_connect(GTK_OBJECT(app.fs->ok_button), 
+			   "clicked",
+			   (GtkSignalFunc)file_load_cb,
+			   (gpointer) frame);
+
+	gtk_widget_show(GTK_WIDGET(app.fs));
+	gtk_window_set_modal (GTK_WINDOW(app.fs), TRUE);
+}
+
+static void
+verb_FileSave_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
+{
+	Buffer *buffer;
+	BonoboViewFrame *view_frame;
 
 	if (!(view_frame = get_active_view_frame (frame))) {
 		g_warning ("unable to get active view frame");
 		return;
 	}
 
-	if (!(buffer = gtk_object_get_data(GTK_OBJECT(view_frame),"buffer"))) {
+	if (!(buffer = gtk_object_get_data(GTK_OBJECT(view_frame),"gshell:buffer"))) {
 		g_warning ("unable to get active buffer");
 		return;
 	}
 
-	if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-				       "IDL:Bonobo/PersistFile:1.0")) {
+	if (bonobo_object_client_has_interface(buffer->server,
+					       "IDL:Bonobo/PersistFile:1.0",
+					       NULL)) {
 		buffer_save_pf (buffer, buffer->name);
-	} else if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-					      "IDL:Bonobo/PersistStream:1.0")) {
+	} else if (bonobo_object_client_has_interface(buffer->server,
+						      "IDL:Bonobo/PersistStream:1.0",
+						      NULL)) {
 		buffer_save_ps (buffer, buffer->name);
 	} else {
 		g_warning ("no storage interface found");
 	}
 }
 
-void  
-file_menu_save_as_cb (BonoboUIHandler *uih, void *data, char *path)
+static void
+verb_FileSaveAs_cb (BonoboUIComponent *component, Frame *frame, const char *cname)
 {
-	Frame *frame;
 	BonoboViewFrame *view_frame;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) return;
 	if (!(view_frame = get_active_view_frame (frame))) return;
 	
 	app.fs=GTK_FILE_SELECTION(gtk_file_selection_new(_("Save As")));
@@ -406,10 +609,18 @@ file_menu_save_as_cb (BonoboUIHandler *uih, void *data, char *path)
 	gtk_signal_connect(GTK_OBJECT(app.fs->ok_button), 
 			   "clicked",
 			   (GtkSignalFunc)file_save_as_cb,
-			   (gpointer)uih);
+			   (gpointer) frame);
 
 	gtk_widget_show(GTK_WIDGET(app.fs));
 	gtk_window_set_modal (GTK_WINDOW(app.fs), TRUE);
 }
 
-
+BonoboUIVerb inout_verbs[] = {
+    BONOBO_UI_UNSAFE_VERB ("FileOpen", verb_FileOpen_cb),
+    BONOBO_UI_UNSAFE_VERB ("LaunchControl", verb_LaunchControl_cb),
+    BONOBO_UI_UNSAFE_VERB ("LaunchEmbeddable", verb_LaunchEmbeddable_cb),
+    BONOBO_UI_UNSAFE_VERB ("FileLoad", verb_FileLoad_cb),
+    BONOBO_UI_UNSAFE_VERB ("FileSave", verb_FileSave_cb),
+    BONOBO_UI_UNSAFE_VERB ("FileSaveAs", verb_FileSaveAs_cb),
+    BONOBO_UI_VERB_END
+};
