@@ -388,3 +388,48 @@ efs_fsstat (EFSDir *root, EFSFSStat *fsstat)
 
 	return root->efs->driver->sops->fsstat (root, fsstat);
 }
+
+/**
+ * efs_node_close
+ * @node: file or directory descriptor
+ *
+ * Description: closes the file or directory descriptor.
+ *
+ */
+
+EFSResult
+efs_node_close (EFSNode *node)
+{
+	g_return_val_if_fail (node != NULL, EFS_ERR_INVAL);
+
+	if (node->mode & EFS_FILE)
+		return efs_file_close (node);
+	else
+		return efs_dir_close (node);
+}
+
+/**
+ * efs_file_open:
+ *
+ * see efs_node_open()
+ */
+
+EFSResult
+efs_file_open (EFSFile **file, EFSDir *dir, const char *path, gint flags)
+{
+	return efs_node_open (file, dir, path, flags, EFS_FILE);
+}
+
+
+/**
+ * efs_dir_open:
+ *
+ * see efs_node_open()
+ */
+
+EFSResult
+efs_dir_open (EFSDir **dir, EFSDir *parent, const char *path, gint flags)
+{
+	return efs_node_open (dir, parent, path, flags, EFS_DIR);
+}
+
