@@ -83,39 +83,31 @@ typedef struct {
 } EFSSuperOps;
 
 typedef struct {
-	EFSResult (*file_open)     (EFSFile **file, EFSDir *dir, 
-				    const char *path, gint flags);
-	EFSResult (*file_close)    (EFSFile *file);
+	EFSResult (*node_open)     (EFSNode **node, EFSDir *dir, 
+				    const char *path, gint flags, gint type);
+	EFSResult (*node_close)    (EFSNode *node);
 	EFSResult (*file_seek)     (EFSFile *file, gint32 offset, gint whence,
 				    guint32 *pos);
+	EFSResult (*dir_seek)      (EFSDir *dir, guint32 offset);
 	EFSResult (*file_read)     (EFSFile *file, gpointer buf, gint32 count,
 				    gint32 *bytes_read);
+	EFSResult (*dir_read)      (EFSDir *dir, EFSDirEntry *de);
 	EFSResult (*file_write)    (EFSFile *file, gpointer buf, gint32 count);
 	EFSResult (*file_trunc)    (EFSFile *file, guint32 size);
 	EFSResult (*type_set)      (EFSNode *node, guint32 type);
 	EFSResult (*type_get)      (EFSNode *node, guint32 *type);
-	EFSResult (*stat)          (EFSDir *dir, const char *path, 
-				    EFSStat *stat);
+	EFSResult (*node_stat)     (EFSNode *node, EFSStat *stat);
 	EFSResult (*erase)         (EFSDir *dir, const char *path);
+	EFSResult (*rename)        (EFSDir *dir, const char *old_path, 
+				    const char *new_path);
 } EFSFileOps;
 
-typedef struct {
-	EFSResult (*dir_open)       (EFSDir **dir, EFSDir *parent, 
-				     const char *path, gint flags);
-	EFSResult (*dir_close)      (EFSDir *dir);
-	EFSResult (*dir_seek)       (EFSDir *dir, guint32 offset);
-	EFSResult (*dir_read)       (EFSDir *dir, EFSDirEntry *de);
-	EFSResult (*rename)         (EFSDir *dir, const char *old_path, 
-				     const char *new_path);
-} EFSDirOps;
-
 struct _EFSDriver {
 	gchar       *drivername;
 	gboolean     encrypted;
 	gchar       *description;
 	EFSSuperOps *sops;
 	EFSFileOps  *fops;
-	EFSDirOps   *dops;
 };
 
 EFSDriver*   efs_find_driver    (gchar *drivername);
