@@ -7,8 +7,8 @@
  *	Michael Meeks (michael@helixcode.com)
  */
 #include <config.h>
-#include <gnome.h>
-#include <bonobo/bonobo.h>
+#include <bonobo/bonobo-moniker.h>
+#include <bonobo/bonobo-moniker-util.h>
 #include <liboaf/liboaf.h>
 
 #include "bonobo-moniker-query.h"
