@@ -4,17 +4,7 @@
  * Author:
  *   Dietmar Maurer (dietmar@maurer-it.com)
  *
- *
- * Problems:
- *
- * do we really need open and create functions? maybe we can use open and
- * a special flag O_CREATE (like in stdio)
- *
- * storage_copy_to: ??? 
- *      idl: copy_to (in string path, in Storage dest, is string new_path)
- *
- * list_contents: bad interface! redesign necessary?
- *
+ * Copyright (C) 2000 Maurer IT Systemlsungen KEG
  */
 
 #include <config.h>
@@ -58,9 +48,58 @@ real_get_info (BonoboStorage *storage,
 	       const Bonobo_StorageInfoFields mask,
 	       CORBA_Environment *ev)
 {
-	g_warning ("Not implemented");
+	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
+	EFSNode *node;
+	EFSResult result;
+	EFSStat st;
+	Bonobo_StorageInfo *si;
+	gchar *content_type = NULL;
 
-	return CORBA_OBJECT_NIL;
+	if ((result = efs_node_open 
+	     (&node, storage_efs->dir, path, EFS_READ, 0))) {
+		if (result == EFS_ERR_NOENT)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotFound, NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
+		
+		return CORBA_OBJECT_NIL;
+	}
+
+	if (efs_node_stat (node, &st)) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
+		efs_node_close (node);
+		return CORBA_OBJECT_NIL;
+	}
+
+	if ((mask & Bonobo_FIELD_CONTENT_TYPE) &&
+	    (efs_strtype_get (node, &content_type))) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
+		efs_node_close (node);
+		return CORBA_OBJECT_NIL;
+	}
+
+	efs_node_close (node);
+	
+	si = Bonobo_StorageInfo__alloc ();
+
+	si->size = st.size;
+	si->name = CORBA_string_dup (path);
+
+	if (st.type == EFS_DIR) 
+		si->type = Bonobo_STORAGE_TYPE_DIRECTORY;
+	else 
+		si->type = Bonobo_STORAGE_TYPE_REGULAR;
+
+	if (content_type) 
+		si->content_type = CORBA_string_dup (content_type);
+	else  
+		si->content_type = NULL;
+
+	return si;
 }
 
 static void
@@ -70,7 +109,40 @@ real_set_info (BonoboStorage *storage,
 	       const Bonobo_StorageInfoFields mask,
 	       CORBA_Environment *ev)
 {
-	g_warning ("Not implemented");
+	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
+	EFSNode *node;
+	EFSResult result;
+
+	if (mask !=  Bonobo_FIELD_CONTENT_TYPE) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_NoPermission, NULL);
+		return;
+	}
+
+	if ((result = efs_node_open 
+	     (&node, storage_efs->dir, path, EFS_WRITE, 0))) {
+		
+		if (result == EFS_ERR_NOENT)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotFound, NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
+		return;
+	}
+
+	if ((result = efs_strtype_set (node, info->content_type))) {
+		
+		if (result == EFS_ERR_PERM)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_NoPermission, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
+	}
+
+	efs_node_close (node);
 }
 
 static BonoboStream *
@@ -79,7 +151,7 @@ real_open_stream (BonoboStorage *storage, const CORBA_char *path,
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
 
-	return bonobo_stream_efs_open (storage_efs, path, mode);
+	return bonobo_stream_efs_open (storage_efs, path, mode, ev);
 }
 
 
@@ -208,10 +280,21 @@ real_erase (BonoboStorage *storage, const CORBA_char *path,
 	    CORBA_Environment *ev)
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
+        EFSResult result;
 
-	if (efs_erase (storage_efs->dir, path)) {
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
-				     ex_Bonobo_Storage_NotFound, NULL);
+	if ((result = efs_erase (storage_efs->dir, path))) {
+
+		if (result == EFS_ERR_NOENT) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotFound, 
+					     NULL);
+		else if (result == EFS_ERR_NOTEMPTY) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotEmpty, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
 	}
 }
 
@@ -269,23 +352,47 @@ bonobo_storage_efs_get_type (void)
  *
  * Returns the BonoboStorage GTK object.
  */
-BonoboStorage *
-bonobo_storage_efs_open (const gchar *path, gint flags, gint mode)
+static BonoboStorage *
+bonobo_storage_efs_open (const gchar *path, gint flags, gint mode, 
+			 CORBA_Environment *ev)
 {
 	BonoboStorageEFS *sefs;
+	EFSResult result;
 	gint efs_flags = 0;
 
 	efs_flags = bonobo_mode_to_efs (flags);
 
 	sefs = gtk_type_new (bonobo_storage_efs_get_type ());
 
-	if (efs_open (&sefs->dir, path, efs_flags, mode, NULL)) {
+	if ((result = efs_open (&sefs->dir, path, efs_flags, mode, NULL))) {
 		bonobo_object_unref (BONOBO_OBJECT (sefs));
+
+		if (result == EFS_ERR_NOENT) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotFound, 
+					     NULL);
+		else if (result == EFS_ERR_PERM) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NoPermission, 
+					     NULL);
+		else if (result == EFS_ERR_EXISTS) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NameExists, 
+					     NULL);
+		else if (result == EFS_ERR_NOTFILE) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotStorage, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
 		return NULL;
 	}
     
 	if (!create_storage_efs_server (sefs)) {
 		bonobo_object_unref (BONOBO_OBJECT (sefs));
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
 		return NULL;
 	}
 
