@@ -4,6 +4,7 @@
  * Author:
  *   Dietmar Maurer (dietmar@maurer-it.com)
  *
+ * Copyright (C) 2000 Maurer IT Systemlsungen KEG
  */
 
 #include <config.h>
@@ -57,43 +58,101 @@ bonobo_stream_efs_destroy (GtkObject *object)
 }
 
 static Bonobo_StorageInfo*
-real_get_info (BonoboStream *stream,
+real_get_info (BonoboStream *stream, 
 	       const Bonobo_StorageInfoFields mask,
 	       CORBA_Environment *ev)
-{
-	g_warning ("Not implemented");
-
-	return CORBA_OBJECT_NIL;
-}
-
-static void
-real_set_info (BonoboStream *stream,
-	       const Bonobo_StorageInfo *info,
-	       const Bonobo_StorageInfoFields mask,
-	       CORBA_Environment *ev)
-{
-	g_warning ("Not implemented");
-}
-
-static void
-real_write (BonoboStream *stream, const Bonobo_Stream_iobuf *buffer,
-	    CORBA_Environment *ev)
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
+	Bonobo_StorageInfo *si;
+	EFSStat st;
+	gchar *content_type = NULL;
 
-	if (efs_file_write (stream_efs->file, buffer->_buffer, 
-			    buffer->_length)) {
+	if (efs_node_stat (stream_efs->file, &st)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Stream_IOError, NULL);
+		
+		return CORBA_OBJECT_NIL;
+	}
+	
+	if ((mask & Bonobo_FIELD_CONTENT_TYPE) &&
+	    (efs_strtype_get (stream_efs->file, &content_type))) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
+		return CORBA_OBJECT_NIL;
+	}
+
+	si = Bonobo_StorageInfo__alloc ();
+
+	si->size = st.size;
+	si->name = NULL;
+
+	if (st.type == EFS_DIR) 
+		si->type = Bonobo_STORAGE_TYPE_DIRECTORY;
+	else 
+		si->type = Bonobo_STORAGE_TYPE_REGULAR;
+
+	if (content_type) 
+		si->content_type = CORBA_string_dup (content_type);
+	else  
+		si->content_type = NULL;
+
+	return si;
+}
+
+static void
+real_set_info (BonoboStream *stream, 
+	       const Bonobo_StorageInfo *info,
+	       const Bonobo_StorageInfoFields mask, 
+	       CORBA_Environment *ev)
+{
+	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
+	EFSResult result;
+
+	if (mask !=  Bonobo_FIELD_CONTENT_TYPE) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Stream_NoPermission, NULL);
 		return;
 	}
 
-	return;
+	if ((result = efs_strtype_set(stream_efs->file, info->content_type))) {
+		
+		if (result == EFS_ERR_PERM)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_NoPermission, 
+					     NULL);
+		else
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_IOError, NULL);
+	}
 }
 
 static void
-real_read (BonoboStream *stream, CORBA_long count,
-	   Bonobo_Stream_iobuf ** buffer,
+real_write (BonoboStream *stream, 
+	    const Bonobo_Stream_iobuf *buffer,
+	    CORBA_Environment *ev)
+{
+	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
+	EFSResult result;
+
+	if ((result = efs_file_write (stream_efs->file, buffer->_buffer, 
+				   buffer->_length))) {
+		
+		if (result == EFS_ERR_PERM) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_NoPermission, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_IOError, NULL);
+		
+		return;
+	}
+}
+
+static void
+real_read (BonoboStream *stream, 
+	   CORBA_long count,
+	   Bonobo_Stream_iobuf ** buffer, 
 	   CORBA_Environment *ev)
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
@@ -120,29 +179,45 @@ real_read (BonoboStream *stream, CORBA_long count,
 		CORBA_free (data);
 		CORBA_free (*buffer);
 		*buffer = NULL;
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
-				     ex_Bonobo_Stream_IOError, NULL);
+
+		if (result == EFS_ERR_PERM)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_NoPermission, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_IOError, NULL);
 	}
 }
 
 static CORBA_long
-real_seek (BonoboStream *stream, CORBA_long offset, Bonobo_Stream_SeekType whence,
+real_seek (BonoboStream *stream, 
+	   CORBA_long offset, 
+	   Bonobo_Stream_SeekType whence, 
 	   CORBA_Environment *ev)
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
-	int fw;
+	EFSResult result;
+	gint efs_whence;
 	guint32 pos;
 
 	if (whence == Bonobo_Stream_SEEK_CUR)
-		fw = EFS_SEEK_CUR;
+		efs_whence = EFS_SEEK_CUR;
 	else if (whence == Bonobo_Stream_SEEK_END)
-		fw = EFS_SEEK_END;
+		efs_whence = EFS_SEEK_END;
 	else
-		fw = EFS_SEEK_SET;
+		efs_whence = EFS_SEEK_SET;
 	
-	if (efs_file_seek (stream_efs->file, offset, fw, &pos)) {
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
-				     ex_Bonobo_Stream_IOError, NULL);
+	if ((result = efs_file_seek(stream_efs->file, offset, efs_whence, 
+				    &pos))) {
+		
+		if (result == EFS_ERR_NOSEEK)
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_NotSupported, 
+					     NULL);
+		else
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Stream_IOError, NULL);
 		return 0;
 	}
 	
@@ -150,32 +225,36 @@ real_seek (BonoboStream *stream, CORBA_long offset, Bonobo_Stream_SeekType whenc
 }
 
 static void
-real_truncate (BonoboStream *stream, const CORBA_long new_size, 
+real_truncate (BonoboStream *stream, 
+	       const CORBA_long new_size, 
 	       CORBA_Environment *ev)
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
-	EFSResult res;
+	EFSResult result;
 
-	res = efs_file_trunc (stream_efs->file, new_size);
+	result = efs_file_trunc (stream_efs->file, new_size);
 
-	if (res == EFS_ERR_NOSEEK) 
+	if (result == EFS_ERR_NOSEEK) 
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
 				     ex_Bonobo_Stream_NotSupported, NULL);
 
-	else if (res == EFS_ERR_PERM) 
+	else if (result == EFS_ERR_PERM) 
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
 				     ex_Bonobo_Stream_NoPermission, NULL);
 
-	else if (res != EFS_ERR_OK) 
+	else if (result != EFS_ERR_OK) 
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
 				     ex_Bonobo_Stream_IOError, NULL);
 
 }
 
 static void
-real_copy_to (BonoboStream *stream, const CORBA_char *dest,
-	     const CORBA_long bytes, CORBA_long *read_bytes,
-	     CORBA_long *written_bytes, CORBA_Environment *ev)
+real_copy_to (BonoboStream *stream, 
+	      const CORBA_char *dest,
+	      const CORBA_long bytes, 
+	      CORBA_long *read_bytes,
+	      CORBA_long *written_bytes, 
+	      CORBA_Environment *ev)
 {
 	BonoboStreamEFS *sfs = BONOBO_STREAM_EFS (stream);
 	gchar data[4096];
@@ -215,14 +294,16 @@ real_copy_to (BonoboStream *stream, const CORBA_char *dest,
 }
 
 static void
-real_commit (BonoboStream *stream, CORBA_Environment *ev)
+real_commit (BonoboStream *stream, 
+	     CORBA_Environment *ev)
 {
         CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
                              ex_Bonobo_Stream_NotSupported, NULL);
 }
 
 static void
-real_revert (BonoboStream *stream, CORBA_Environment *ev)
+real_revert (BonoboStream *stream, 
+	     CORBA_Environment *ev)
 {
         CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
                              ex_Bonobo_Stream_NotSupported, NULL);
@@ -271,28 +352,60 @@ bonobo_stream_efs_get_type (void)
 }
 
 BonoboStream *
-bonobo_stream_efs_open (BonoboStorageEFS *storage, const CORBA_char *path, 
-			Bonobo_Storage_OpenMode mode)
+bonobo_stream_efs_open (BonoboStorageEFS *storage, 
+			const CORBA_char *path, 
+			Bonobo_Storage_OpenMode mode,
+			CORBA_Environment *ev)
 {
 	BonoboStreamEFS *stream;
+	EFSResult result;
 	gint efs_mode;
 
-	g_return_val_if_fail (path != NULL, NULL);
-	g_return_val_if_fail (storage != NULL, NULL);
-
-	if (!(stream = gtk_type_new (bonobo_stream_efs_get_type ()))) 
+	if (!(stream = gtk_type_new (bonobo_stream_efs_get_type ()))) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
 		return NULL;
+	}
 
 	efs_mode = bonobo_mode_to_efs (mode);
 
-	if (efs_file_open (&stream->file, storage->dir, path, efs_mode)) {
+	if ((result = efs_file_open 
+	     (&stream->file, storage->dir, path, efs_mode))) {
+		
 		bonobo_object_unref (BONOBO_OBJECT (stream));
+
+		if (result == EFS_ERR_NOENT) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotFound, 
+					     NULL);
+		else if (result == EFS_ERR_PERM) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NoPermission, 
+					     NULL);
+		else if (result == EFS_ERR_EXISTS) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NameExists, 
+					     NULL);
+		else if (result == EFS_ERR_NOTFILE) 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_NotStream, 
+					     NULL);
+		else 
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+					     ex_Bonobo_Storage_IOError, NULL);
+
 		return NULL;
 	}
 	
 	stream->storage = storage;
 	bonobo_object_ref (BONOBO_OBJECT(storage));
-	create_stream_efs_server (stream);
+
+	if (!create_stream_efs_server (stream)) {
+		bonobo_object_unref (BONOBO_OBJECT (stream));
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Storage_IOError, NULL);
+		return NULL;
+	}
 
 	return BONOBO_STREAM (stream);
 }
